==> igniteui-react-16.16.2.tgz: package/esm5/lib/Calendar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { CalendarBase } from "./CalendarBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarHeaderOrientation_$type } from "./CalendarHeaderOrientation";
import { CalendarOrientation_$type } from "./CalendarOrientation";
import { CalendarActiveView_$type } from "./CalendarActiveView";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentDataValueChangedEventArgs } from "./ComponentDataValueChangedEventArgs";
/**
 * @hidden
 */
var Calendar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Calendar, _super);
    function Calendar() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Object.defineProperty(Calendar.prototype, "v", {
        get: function () {
            var ret_ = this.f.c("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "k", {
        get: function () {
            var ret_ = this.f.c("values");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("values", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "u", {
        get: function () {
            var ret_ = this.f.c("activeDate");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("activeDate", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "t", {
        get: function () {
            var ret_ = this.f.c("hideOutsideDays");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("hideOutsideDays", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "s", {
        get: function () {
            var ret_ = this.f.c("hideHeader");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("hideHeader", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "n", {
        get: function () {
            var ret_ = this.f.c("headerOrientation");
            ret_ = enumGetBox(CalendarHeaderOrientation_$type, EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, EnumUtil.parse(CalendarHeaderOrientation_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarHeaderOrientation_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("headerOrientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "o", {
        get: function () {
            var ret_ = this.f.c("orientation");
            ret_ = enumGetBox(CalendarOrientation_$type, EnumUtil.getEnumValue(CalendarOrientation_$type, EnumUtil.parse(CalendarOrientation_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarOrientation_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "w", {
        get: function () {
            var ret_ = this.f.c("visibleMonths");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("visibleMonths", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "l", {
        get: function () {
            var ret_ = this.f.c("activeView");
            ret_ = enumGetBox(CalendarActiveView_$type, EnumUtil.getEnumValue(CalendarActiveView_$type, EnumUtil.parse(CalendarActiveView_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarActiveView_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarActiveView_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("activeView", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "m", {
        get: function () {
            var ret_ = this.f.c("formatOptions");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("formatOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "p", {
        get: function () {
            var ret_ = this.f.c("resourceStrings");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("resourceStrings", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "r", {
        get: function () {
            var ret_ = this.f.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Calendar.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.g("change", function (a) { return _this.change(_this, ComponentDataValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.h("change");
        }
    };
    Calendar.$t = markType(Calendar, 'Calendar', CalendarBase.$);
    return Calendar;
}(CalendarBase));
export { Calendar };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Calendar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { CalendarBase } from "./CalendarBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarHeaderOrientation_$type } from "./CalendarHeaderOrientation";
import { CalendarOrientation_$type } from "./CalendarOrientation";
import { CalendarActiveView_$type } from "./CalendarActiveView";
import { CalendarFormatOptions } from "./CalendarFormatOptions";
import { CalendarResourceStrings } from "./CalendarResourceStrings";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentDataValueChangedEventArgs } from "./ComponentDataValueChangedEventArgs";
/**
 * @hidden
 */
var Calendar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Calendar, _super);
    function Calendar() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Object.defineProperty(Calendar.prototype, "w", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "l", {
        get: function () {
            var ret_ = this.f.n("values");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("values", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "v", {
        get: function () {
            var ret_ = this.f.n("activeDate");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("activeDate", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "u", {
        get: function () {
            var ret_ = this.f.n("hideOutsideDays");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("hideOutsideDays", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "t", {
        get: function () {
            var ret_ = this.f.n("hideHeader");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("hideHeader", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "o", {
        get: function () {
            var ret_ = this.f.n("headerOrientation");
            ret_ = enumGetBox(CalendarHeaderOrientation_$type, EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, this.f.f(CalendarHeaderOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarHeaderOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("headerOrientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "p", {
        get: function () {
            var ret_ = this.f.n("orientation");
            ret_ = enumGetBox(CalendarOrientation_$type, EnumUtil.getEnumValue(CalendarOrientation_$type, this.f.f(CalendarOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "x", {
        get: function () {
            var ret_ = this.f.n("visibleMonths");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("visibleMonths", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "m", {
        get: function () {
            var ret_ = this.f.n("activeView");
            ret_ = enumGetBox(CalendarActiveView_$type, EnumUtil.getEnumValue(CalendarActiveView_$type, this.f.f(CalendarActiveView_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarActiveView_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CalendarActiveView_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("activeView", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "n", {
        get: function () {
            var ret_ = this.f.m("formatOptions", function (a) { return new CalendarFormatOptions(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("formatOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "q", {
        get: function () {
            var ret_ = this.f.m("resourceStrings", function (a) { return new CalendarResourceStrings(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("resourceStrings", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Calendar.prototype, "s", {
        get: function () {
            var ret_ = this.f.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Calendar.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.r("change", function (a) { return _this.change(_this, ComponentDataValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("change");
        }
    };
    Calendar.$t = markType(Calendar, 'Calendar', CalendarBase.$);
    return Calendar;
}(CalendarBase));
export { Calendar };
